@@ -872,6 +872,15 @@ goa_provider_ensure_credentials_sync (GoaProvider     *self,
   ret = GOA_PROVIDER_GET_CLASS (self)->ensure_credentials_sync (self, object, out_expires_in, cancellable, error);
 
  out:
+  if (!ret && error != NULL && *error == NULL)
+    {
+      const gchar *provider_type;
+
+      provider_type = goa_provider_get_provider_type (self);
+      g_critical ("GoaProvider (%s) failed to set error correctly", provider_type);
+      g_set_error_literal (error, GOA_ERROR, GOA_ERROR_NOT_AUTHORIZED, _("Unknown error"));
+    }
+
   g_clear_object (&account);
   return ret;
 }
@@ -981,12 +990,12 @@ static struct
 #ifdef GOA_FACEBOOK_ENABLED
   { GOA_FACEBOOK_NAME, goa_facebook_provider_get_type },
 #endif
-#ifdef GOA_FLICKR_ENABLED
-  { GOA_FLICKR_NAME, goa_flickr_provider_get_type },
-#endif
 #ifdef GOA_WINDOWS_LIVE_ENABLED
   { GOA_WINDOWS_LIVE_NAME, goa_windows_live_provider_get_type },
 #endif
+#ifdef GOA_FLICKR_ENABLED
+  { GOA_FLICKR_NAME, goa_flickr_provider_get_type },
+#endif
 #ifdef GOA_POCKET_ENABLED
   { GOA_POCKET_NAME, goa_pocket_provider_get_type },
 #endif
